@@ -2,13 +2,12 @@ list.map.fun <- function(.data,.expr) {
   eval(.expr,.list.env(.data),environment())
 }
 
-list.map.internal <- function(.data,expr,fun = list.map.fun,
-  envir=parent.frame(2L)) {
-  if(is.null(.data) || length(.data) == 0L) return(list())
+list.map.internal <- function(.data,expr,fun = list.map.fun, envir) {
+  if(is.empty(.data)) return(list())
   l <- lambda(expr)
   xnames <- getnames(.data,character(1L))
   environment(fun) <- envir
-  formals(fun) <- setnames(vector("list",.nfsymbol),
+  formals(fun) <- setnames(vector("pairlist",.nfsymbol),
     c(".data",".expr",l$symbols))
   args <- list(fun,.data,list(l$expr),.data,seq_along(.data),xnames)
   do.call(Map, args)
@@ -19,7 +18,7 @@ list.is.fun <- function(.data,.expr) {
   if(is.logical(x) && length(x) == 1L) x else NA
 }
 
-list.is.internal <- function(.data,cond,envir=parent.frame(2L)) {
+list.is.internal <- function(.data,cond,envir) {
   as.logical(list.map.internal(.data,cond,list.is.fun,envir))
 }
 
@@ -30,11 +29,11 @@ list.findi.fun <- function(.data,.expr) {
   if(is.logical(x) && length(x) == 1L && x) {
     env$.n <- env$.n + 1L
     env$.indices <- c(env$.indices, env$.i)
-    if(env$.n == env$n) stop()
+    if(env$.n == env$n) stop(call. = FALSE)
   }
 }
 
-list.findi.internal <- function(.data,cond,n,envir=parent.frame(2L)) {
+list.findi.internal <- function(.data,cond,n,envir) {
   .i <- 0L
   .n <- 0L
   .indices <- integer()
@@ -46,11 +45,11 @@ list.while.fun <- function(.data,.expr) {
   env <- parent.frame(4L)
   x <- eval(.expr,.list.env(.data),environment())
   if(is.logical(x) && length(x) == 1L && x) env$.i <- env$.i + 1L
-  else stop()
+  else stop(call. = FALSE)
 }
 
-list.order.internal <- function(.data,args,envir=parent.frame(2L)) {
-  if(is.null(.data) || length(.data) == 0L) return(integer())
+list.order.internal <- function(.data,args,envir) {
+  if(is.empty(.data)) return(integer())
   envir <- new.env(parent = envir)
   list2env(list.sort.functions,envir)
   cols <- lapply(args,function(arg) {
@@ -65,15 +64,17 @@ list.search.fun <- function(.data, .expr, .counter, .n,
   q <- eval(.expr, environment(), NULL)
   vq <- !is.na(q)
   if(.counter$i < .n){
-    if(is.logical(q) && length(q) == 1L && !is.na(q)) {
-      if(q) {
+    # for logical vector, only single-valued TRUE will return value;
+    # for other vectors, if it contains any non-NA values,
+    # the vector will be returned
+    if(is.logical(q)) {
+      if(length(q) == 1L && !is.na(q) && q) {
         .counter$i <- .counter$i + length(.data)
         return(.data)
       } else {
         return(NULL)
       }
-    }
-    if(length(q) >= 1L && any(vq)) {
+    } else if(length(q) >= 1L && any(vq)) {
       .counter$i <- .counter$i + length(which(vq))
       return(q[vq])
     }
