@@ -3,7 +3,6 @@
 #' @param .data \code{list}
 #' @param cond A logical lambda expression
 #' @param na.rm logical. If true all \code{NA} values are removed
-#' @param envir The environment to evaluate mapping function
 #' @name list.any
 #' @export
 #' @examples
@@ -14,6 +13,6 @@
 #' list.any(x,type=="B")
 #' list.any(x,mean(unlist(score))>=6)
 #' }
-list.any <- function(.data,cond,na.rm=FALSE,envir=parent.frame()) {
-  length(list.findi.internal(.data,substitute(cond),n = 1,envir = envir)) > 0L
+list.any <- function(.data,cond,na.rm=FALSE) {
+  any(list.is.internal(.data,substitute(cond),parent.frame()),na.rm = na.rm)
 }
