@@ -4,7 +4,6 @@
 #' @param expr A lambda expression
 #' @param ... Additional parameters passed to \code{unique}
 #' @param sort.cases \code{logical}. if \code{TRUE} the cases will be sorted in ascending order.
-#' @param envir The environment to evaluate mapping function
 #' @name list.class
 #' @export
 #' @examples
@@ -23,8 +22,8 @@
 #' list.class(x,interest)
 #' list.class(x,names(lang))
 #' }
-list.class <- function(.data,expr,...,sort.cases=TRUE,envir=parent.frame()) {
-  values <- list.map.internal(.data,substitute(expr),envir = envir)
+list.class <- function(.data,expr,...,sort.cases=TRUE) {
+  values <- list.map.internal(.data,substitute(expr),envir = parent.frame())
   cases <- unique(unlist(values,use.names = FALSE),...)
   names(cases) <- cases
   if(sort.cases)  cases <- sort(cases)
