@@ -2,7 +2,6 @@
 #'
 #' @param .data \code{list}
 #' @param cond A logical lambda expression
-#' @param envir The environment to evaluate mapping function
 #' @name list.count
 #' @export
 #' @examples
@@ -13,6 +12,6 @@
 #' list.count(x,type=="B")
 #' list.count(x,min(unlist(score)) >= 9)
 #' }
-list.count <- function(.data,cond,envir = parent.frame()) {
-  length(which(list.is.internal(.data,substitute(cond),envir = envir)))
+list.count <- function(.data,cond) {
+  length(which(list.is.internal(.data,substitute(cond),envir = parent.frame())))
 }
