@@ -2,7 +2,6 @@
 #'
 #' @param .data \code{list}
 #' @param cond A logical lambda expression
-#' @param envir The environment to evaluate mapping function
 #' @name list.filter
 #' @export
 #' @examples
@@ -13,6 +12,6 @@
 #' list.filter(x,type=="B")
 #' list.filter(x,min(score$c1,score$c2) >= 8)
 #' }
-list.filter <- function(.data,cond,envir = parent.frame()) {
-  list.clean(.data[list.is.internal(.data,substitute(cond),envir)])
+list.filter <- function(.data,cond) {
+  list.clean(.data[list.is.internal(.data,substitute(cond),parent.frame())])
 }
