@@ -3,7 +3,6 @@
 #' @param .data \code{list}
 #' @param cond A logical lambda expression
 #' @param n The number of items to find
-#' @param envir The environment to evaluate mapping function
 #' @name list.find
 #' @export
 #' @examples
@@ -14,6 +13,6 @@
 #' list.find(x,type=="B",1)
 #' list.find(x,min(score$c1,score$c2) >= 9)
 #' }
-list.find <- function(.data,cond,n=1L,envir=parent.frame()) {
-  .data[list.findi.internal(.data,substitute(cond),n,envir)]
+list.find <- function(.data,cond,n=1L) {
+  .data[list.findi.internal(.data,substitute(cond),n,parent.frame())]
 }
