@@ -2,7 +2,7 @@
 #'
 #' @param .data \code{list}
 #' @param index The index at which the lists are inserted
-#' @param ... A series of lists
+#' @param ... A group of lists
 #' @name list.insert
 #' @export
 #' @examples
@@ -13,6 +13,10 @@
 #' list.if(x,2,p2.1=list(type="B",score=list(c1=8,c2=9)))
 #' }
 list.insert <- function(.data,index,...) {
-  lists <- list(...)
-  c(.data[0L:max(0L,index-1L)],lists,.data[index:length(.data)])
+  values <- if(is.list(.data)) list(...) else c(...)
+  n <- length(.data)
+  if(index < -n) stop("Invalid index")
+  if(index < 0L) index <- n+index+1
+  c(.data[0L:max(0L,index-1L)],values,
+    if(index <= n) .data[index:length(.data)] else NULL)
 }
