@@ -3,7 +3,6 @@
 #'
 #' @param .data \code{list}
 #' @param expr A lambda expression
-#' @param envir The environment to evaluate mapping function
 #' @name list.iter
 #' @export
 #' @return \code{invisible(.data)}
@@ -15,7 +14,7 @@
 #' list.iter(x,cat(paste(type,"\n")))
 #' list.iter(x,cat(str(.)))
 #' }
-list.iter <- function(.data,expr,envir = parent.frame()) {
-  list.map.internal(.data,substitute(expr),envir = envir)
+list.iter <- function(.data,expr) {
+  list.map.internal(.data,substitute(expr),envir = parent.frame())
   invisible(.data)
 }
