@@ -3,7 +3,6 @@
 #' @param .data \code{list}
 #' @param ... A group of lambda expressions
 #' @param keep.names Whether to keep the names of \code{x} in the result
-#' @param .envir The environment to evaluate mapping function
 #' @name list.order
 #' @export
 #' @examples
@@ -15,7 +14,7 @@
 #' list.order(x,min(score$c1,score$c2))
 #' list.order(x,min(score$c1,score$c2),keep.names=TRUE)
 #' }
-list.order <- function(.data,...,keep.names=FALSE,.envir = parent.frame()) {
-  result <- list.order.internal(.data,dots(...),envir = .envir)
+list.order <- function(.data,...,keep.names=FALSE) {
+  result <- list.order.internal(.data,dots(...),envir = parent.frame())
   if(keep.names) setnames(result,names(.data)) else result
 }
