@@ -2,7 +2,6 @@
 #'
 #' @param .data \code{list}
 #' @param ... A group of implicit labmda expressions
-#' @param .envir The environment to evaluate mapping function
 #' @name list.select
 #' @export
 #' @examples
@@ -15,8 +14,8 @@
 #' list.select(x,type,score)
 #' list.select(x,type,score.range=range(unlist(score)))
 #' }
-list.select <- function(.data,...,.envir = parent.frame()) {
+list.select <- function(.data,...) {
   args <- set_argnames(dots(...))
   quote <- as.call(c(quote(list),args))
-  list.map.internal(.data,quote,envir = .envir)
+  list.map.internal(.data,quote,envir = parent.frame())
 }
