@@ -3,7 +3,6 @@
 #'
 #' @param .data \code{list}
 #' @param cond A logical lambda expression
-#' @param envir The environment to evaluate mapping function
 #' @name list.which
 #' @export
 #' @examples
@@ -14,6 +13,6 @@
 #' list.which(x,type=="B")
 #' list.which(x,min(score$c1,score$c2) >= 8)
 #' }
-list.which <- function(.data,cond,envir = parent.frame()) {
-  which(list.is.internal(.data,substitute(cond),envir = envir))
+list.which <- function(.data,cond) {
+  which(list.is.internal(.data,substitute(cond),envir = parent.frame()))
 }
